@@ -9,6 +9,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import errno
 import logging
 import os.path
 
@@ -114,7 +115,46 @@ class Config(object):
         'earliest_version': None,
 
         # The template used by reno new to create a note.
-        'template': _TEMPLATE
+        'template': _TEMPLATE,
+
+        # The RE pattern used to match the repo tags representing a valid
+        # release version. The pattern is compiled with the verbose and unicode
+        # flags enabled.
+        'release_tag_re': '''
+            ((?:[\d.ab]|rc)+)  # digits, a, b, and rc cover regular and
+                               # pre-releases
+        ''',
+
+        # The RE pattern used to check if a valid release version tag is also a
+        # valid pre-release version. The pattern is compiled with the verbose
+        # and unicode flags enabled. The pattern must define a group called
+        # 'pre_release' that matches the pre-release part of the tag and any
+        # separator, e.g for pre-release version '12.0.0.0rc1' the default RE
+        # pattern will identify '.0rc1' as the value of the group
+        # 'pre_release'.
+        'pre_release_tag_re': '''
+            (?P<pre_release>\.\d+(?:[ab]|rc)+\d*)$
+        ''',
+
+        # The pattern for names for branches that are relevant when
+        # scanning history to determine where to stop, to find the
+        # "base" of a branch. Other branches are ignored.
+        'branch_name_re': 'stable/.+',
+
+        # The identifiers and names of permitted sections in the
+        # release notes, in the order in which the final report will
+        # be generated. A prelude section will always be automatically
+        # inserted before the first element of this list.
+        'sections': [
+            ['features', 'New Features'],
+            ['issues', 'Known Issues'],
+            ['upgrade', 'Upgrade Notes'],
+            ['deprecations', 'Deprecation Notes'],
+            ['critical', 'Critical Issues'],
+            ['security', 'Security Issues'],
+            ['fixes', 'Bug Fixes'],
+            ['other', 'Other Notes'],
+        ],
     }
 
     @classmethod
@@ -152,8 +192,12 @@ class Config(object):
             with open(self._filename, 'r') as fd:
                 self._contents = yaml.safe_load(fd)
         except IOError as err:
-            LOG.info('did not load config file %s: %s',
-                     self._filename, err)
+            if err.errno == errno.ENOENT:
+                LOG.info('no configuration file in %s',
+                         self._filename)
+            else:
+                LOG.warning('did not load config file %s: %s',
+                            self._filename, err)
         else:
             self.override(**self._contents)
 
